package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.DataMappingProvider;
import com.ynet.life.loaf.TableConfig;
import com.ynet.life.loaf.jdbc.LoafPreparedData;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/UpdateChangedDataBatchAction.class */
public class UpdateChangedDataBatchAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private int opType;
    private String businessCodeField;
    private String businessCode;
    private String iCollName;
    private boolean throwException = true;
    private List copyFields;

    /* JADX WARN: Finally extract failed */
    public String execute(Context context) throws GENEException {
        try {
            try {
                String currentBusinessCode = this.businessCodeField != null ? (String) context.get(this.businessCodeField) : this.businessCode;
                IndexedCollection inputIColl = (IndexedCollection) context.get(this.iCollName);
                int size = inputIColl.size();
                if (size != 0) {
                    Connection connection = LifeDBAccess.getConnection(getDataSource());
                    TableConfig tableConfig = DataMappingProvider.getTableConfig(currentBusinessCode);
                    PreparedStatement ps = null;
                    for (int i = 0; i < size; i++) {
                        try {
                            KeyedCollection kColl = (KeyedCollection) inputIColl.get(i);
                            copyFieldsIntoKeyedCollection(context, kColl);
                            List inputList = new LinkedList();
                            if (ps == null) {
                                String preparedSQL = DataMappingProvider.getPrepareSQLAndData(tableConfig, this.opType, kColl, inputList, false);
                                Trace.logDebug("LOAF", "批量操作SQL--->".concat(String.valueOf(preparedSQL)));
                                ps = connection.prepareStatement(preparedSQL);
                            } else {
                                DataMappingProvider.getPrepareSQLAndData(tableConfig, this.opType, kColl, inputList, true);
                            }
                            prepareInputData(inputList, ps);
                            Trace.logDebug("LOAF", "输入参数列表--->".concat(String.valueOf(inputList)));
                            int updateCount = 0;
                            try {
                                updateCount = ps.executeUpdate();
                            } catch (SQLException se) {
                                if (this.throwException) {
                                    throw new TranFailException("EBLN0000", se);
                                }
                                context.put("GENEException", se);
                            }
                            if (4 == this.opType && updateCount == 0) {
                                DataMappingProvider.doTableOperation(connection, tableConfig, 1, kColl);
                            }
                        } catch (Throwable th) {
                            if (ps != null) {
                                try {
                                    ps.close();
                                } catch (SQLException se2) {
                                    Trace.logWarning("LOAF", "JDBC对象关闭异常", se2);
                                }
                            }
                            throw th;
                        }
                    }
                    if (ps != null) {
                        try {
                            ps.close();
                        } catch (SQLException se3) {
                            Trace.logWarning("LOAF", "JDBC对象关闭异常", se3);
                        }
                    }
                    LifeDBAccess.releaseConnection(getDataSource(), connection);
                    return "0";
                }
                LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
                return "0";
            } catch (SQLException se4) {
                Trace.logError("LOAF", se4.getMessage(), se4);
                throw new TranFailException(se4);
            }
        } catch (Throwable th2) {
            LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
            throw th2;
        }
    }

    private void copyFieldsIntoKeyedCollection(Context context, KeyedCollection kColl) {
        if (this.copyFields != null) {
            for (String fieldName : this.copyFields) {
                kColl.put(fieldName, context.get(fieldName));
            }
        }
    }

    private void prepareInputData(List inputList, PreparedStatement statement) throws SQLException {
        int inputSize = inputList.size();
        for (int i = 1; i <= inputSize; i++) {
            ((LoafPreparedData) inputList.get(i - 1)).fillStatement(statement, i);
        }
    }

    public void setOpType(String opType) {
        this.opType = DataMappingProvider.getOpType(opType);
    }

    public void setBusinessCodeField(String businessCodeField) {
        this.businessCodeField = businessCodeField;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setThrowException(String throwException) {
        this.throwException = Boolean.valueOf(throwException).booleanValue();
    }

    public void setCopyFields(String inputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(inputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.copyFields = result;
    }
}
